@@ -1,6 +1,6 @@
 APP = 'apigeecli'
 CMD = 'apigee'
-__version__ = '0.46.0'
+__version__ = '0.46.1'
 description = 'Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support'
 long_description = """Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"""
 
@@ -17,7 +17,9 @@ APIGEE_ADMIN_API_URL = 'https://api.enterprise.apigee.com'
 APIGEE_OAUTH_URL = 'https://login.apigee.com/oauth/token'
 APIGEE_ZONENAME_OAUTH_URL = 'https://{zonename}.login.apigee.com/oauth/token'
 APIGEE_ZONENAME = getenv('APIGEE_ZONENAME')
-APIGEE_CLI_IS_MACHINE_USER = True if getenv('APIGEE_CLI_IS_MACHINE_USER') in (True, 'True', 'true', '1') else False
+APIGEE_CLI_IS_MACHINE_USER = (
+    True if getenv('APIGEE_CLI_IS_MACHINE_USER') in (True, 'True', 'true', '1') else False
+)
 APIGEE_SAML_LOGIN_URL = 'https://{zonename}.login.apigee.com/passcode'
 APIGEE_ORG = getenv('APIGEE_ORG')
 
