@@ -19,7 +19,16 @@ def apis():
 
 
 def _delete_api_proxy_revision(
-    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    **kwargs,
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -57,12 +66,16 @@ def _deploy_api_proxy_revision(
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
-        .deploy_api_proxy_revision(name, environment, revision_number, delay=delay, override=override)
+        .deploy_api_proxy_revision(
+            name, environment, revision_number, delay=delay, override=override
+        )
         .text
     )
 
 
-@apis.command(help='Deploys a revision of an existing API proxy to an environment in an organization.')
+@apis.command(
+    help='Deploys a revision of an existing API proxy to an environment in an organization.'
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -85,11 +98,21 @@ def deploy_revision(*args, **kwargs):
 
 
 def _delete_undeployed_revisions(
-    username, password, mfa_secret, token, zonename, org, profile, name, save_last=0, dry_run=False, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    save_last=0,
+    dry_run=False,
+    **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).delete_undeployed_revisions(
-        name, save_last=save_last, dry_run=dry_run
-    )
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).delete_undeployed_revisions(name, save_last=save_last, dry_run=dry_run)
 
 
 @apis.command(
@@ -99,8 +122,17 @@ def _delete_undeployed_revisions(
 @common_verbose_options
 @common_silent_options
 @click.option('-n', '--name', help='name', required=True)
-@click.option('--save-last', type=click.INT, help='denotes not to delete the N most recent revisions', default=0)
-@click.option('--dry-run/--no-dry-run', default=False, help='show revisions to be deleted but do not delete')
+@click.option(
+    '--save-last',
+    type=click.INT,
+    help='denotes not to delete the N most recent revisions',
+    default=0,
+)
+@click.option(
+    '--dry-run/--no-dry-run',
+    default=False,
+    help='show revisions to be deleted but do not delete',
+)
 def clean(*args, **kwargs):
     _delete_undeployed_revisions(*args, **kwargs)
 
@@ -119,8 +151,13 @@ def _export_api_proxy(
     output_file=None,
     **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).export_api_proxy(
-        name, revision_number, fs_write=True, output_file=output_file if output_file else f'{name}.zip'
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).export_api_proxy(
+        name,
+        revision_number,
+        fs_write=True,
+        output_file=output_file if output_file else f'{name}.zip',
     )
 
 
@@ -132,16 +169,26 @@ def _export_api_proxy(
 @common_silent_options
 @click.option('-n', '--name', help='name', required=True)
 @click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
-@click.option('-O', '--output-file', help='specify output file (defaults to API_NAME.zip)', default=None)
+@click.option(
+    '-O', '--output-file', help='specify output file (defaults to API_NAME.zip)', default=None
+)
 def export(*args, **kwargs):
     _export_api_proxy(*args, **kwargs)
 
 
-def _get_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).get_api_proxy(name).text
+def _get_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
+    return (
+        Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_api_proxy(name)
+        .text
+    )
 
 
-@apis.command(help='Gets an API proxy by name, including a list of existing revisions of the proxy.')
+@apis.command(
+    help='Gets an API proxy by name, including a list of existing revisions of the proxy.'
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -151,9 +198,20 @@ def get(*args, **kwargs):
 
 
 def _list_api_proxies(
-    username, password, mfa_secret, token, zonename, org, profile, prefix=None, format='json', **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    prefix=None,
+    format='json',
+    **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).list_api_proxies(prefix=prefix)
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).list_api_proxies(prefix=prefix)
 
 
 @apis.command(
@@ -167,8 +225,14 @@ def list(*args, **kwargs):
     console.echo(_list_api_proxies(*args, **kwargs))
 
 
-def _list_api_proxy_revisions(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).list_api_proxy_revisions(name).text
+def _list_api_proxy_revisions(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
+    return (
+        Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .list_api_proxy_revisions(name)
+        .text
+    )
 
 
 @apis.command(help='List all revisions for an API proxy.')
@@ -181,7 +245,17 @@ def list_revisions(*args, **kwargs):
 
 
 def _undeploy_api_proxy_revision(
-    username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    environment,
+    revision_number,
+    **kwargs,
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -202,7 +276,17 @@ def undeploy_revision(*args, **kwargs):
 
 
 def _force_undeploy_api_proxy_revision(
-    username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    environment,
+    revision_number,
+    **kwargs,
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -258,10 +342,14 @@ def _pull(
 @click.option('-n', '--name', help='name', required=True)
 @click.option('-r', '--revision-number', type=click.INT, help='revision number', required=True)
 @click.option('-e', '--environment', help='environment', required=True)
-@click.option('--work-tree', help='set the path to the working tree (defaults to current working directory)')
+@click.option(
+    '--work-tree',
+    help='set the path to the working tree (defaults to current working directory)',
+)
 @click.option('--force/--no-force', '-f/-F', default=False, help='force write files')
 @click.option(
-    '--prefix', help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.'
+    '--prefix',
+    help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.',
 )
 @click.option('-b', '--basepath', help='set default basepath in apiproxy/proxies/default.xml')
 def pull(*args, **kwargs):
@@ -327,8 +415,17 @@ These files are Copyright 2015 Apigee Corporation, released under the Apache2 Li
     type=click.Path(exists=True, dir_okay=True, file_okay=False, resolve_path=False),
     required=True,
 )
-@optgroup.group('Deployment options', cls=MutuallyExclusiveOptionGroup, help='The deployment options')
-@optgroup.option('--import-only/--no-import-only', '-i/-I', default=False, help='import only and not deploy')
-@optgroup.option('--seamless-deploy/--no-seamless-deploy', '-s/-S', default=False, help='seamless deploy the bundle')
+@optgroup.group(
+    'Deployment options', cls=MutuallyExclusiveOptionGroup, help='The deployment options'
+)
+@optgroup.option(
+    '--import-only/--no-import-only', '-i/-I', default=False, help='import only and not deploy'
+)
+@optgroup.option(
+    '--seamless-deploy/--no-seamless-deploy',
+    '-s/-S',
+    default=False,
+    help='seamless deploy the bundle',
+)
 def deploy(*args, **kwargs):
     _deploy(*args, **kwargs)
