@@ -5,7 +5,9 @@ from tabulate import tabulate
 
 from apigee import APIGEE_ADMIN_API_URL, auth
 
-GET_API_PROXY_DEPLOYMENT_DETAILS_PATH = '{api_url}/v1/organizations/{org}/apis/{api_name}/deployments'
+GET_API_PROXY_DEPLOYMENT_DETAILS_PATH = (
+    '{api_url}/v1/organizations/{org}/apis/{api_name}/deployments'
+)
 
 
 class DeploymentsSerializer:
@@ -14,7 +16,13 @@ class DeploymentsSerializer:
             return deployment_details.text
         revisions = []
         for i in deployment_details.json()['environment']:
-            revisions.append({'name': i['name'], 'revision': [j['name'] for j in i['revision']], 'state': [j['state'] for j in i['revision']]})
+            revisions.append(
+                {
+                    'name': i['name'],
+                    'revision': [j['name'] for j in i['revision']],
+                    'state': [j['state'] for j in i['revision']],
+                }
+            )
         if format == 'json':
             return json.dumps(revisions)
         elif format == 'table':
@@ -63,13 +71,24 @@ class Deployments:
     def api_name(self, value):
         self._api_name = value
 
-    def get_api_proxy_deployment_details(self, formatted=False, format='text', showindex=False, tablefmt='plain', revision_name_only=False):
-        uri = GET_API_PROXY_DEPLOYMENT_DETAILS_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=self._api_name)
+    def get_api_proxy_deployment_details(
+        self,
+        formatted=False,
+        format='text',
+        showindex=False,
+        tablefmt='plain',
+        revision_name_only=False,
+    ):
+        uri = GET_API_PROXY_DEPLOYMENT_DETAILS_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, api_name=self._api_name
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         if formatted:
             if revision_name_only:
-                return DeploymentsSerializer().serialize_details(resp, format, showindex=showindex, tablefmt=tablefmt)
+                return DeploymentsSerializer().serialize_details(
+                    resp, format, showindex=showindex, tablefmt=tablefmt
+                )
             return DeploymentsSerializer().serialize_details(resp, 'text')
         return resp
