@@ -5,11 +5,21 @@ from requests.exceptions import HTTPError
 
 from apigee import APIGEE_ADMIN_API_URL, auth, console
 
-CREATE_A_TARGETSERVER_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers'
-DELETE_A_TARGETSERVER_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
-LIST_TARGETSERVERS_IN_AN_ENVIRONMENT_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers'
-GET_TARGETSERVER_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
-UPDATE_A_TARGETSERVER_PATH = '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
+CREATE_A_TARGETSERVER_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers'
+)
+DELETE_A_TARGETSERVER_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
+)
+LIST_TARGETSERVERS_IN_AN_ENVIRONMENT_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers'
+)
+GET_TARGETSERVER_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
+)
+UPDATE_A_TARGETSERVER_PATH = (
+    '{api_url}/v1/organizations/{org}/environments/{environment}/targetservers/{name}'
+)
 
 
 class TargetserversSerializer:
@@ -19,7 +29,11 @@ class TargetserversSerializer:
             return targetservers.text
         targetservers = targetservers.json()
         if prefix:
-            targetservers = [targetserver for targetserver in targetservers if targetserver.startswith(prefix)]
+            targetservers = [
+                targetserver
+                for targetserver in targetservers
+                if targetserver.startswith(prefix)
+            ]
         if format == 'json':
             return json.dumps(targetservers)
         elif format == 'table':
@@ -65,37 +79,62 @@ class Targetservers:
         self._targetserver_name = value
 
     def create_a_targetserver(self, environment, request_body):
-        uri = CREATE_A_TARGETSERVER_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment)
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
+        uri = CREATE_A_TARGETSERVER_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment
+        )
+        hdrs = auth.set_header(
+            self._auth,
+            headers={'Accept': 'application/json', 'Content-Type': 'application/json'},
+        )
         body = json.loads(request_body)
         resp = requests.post(uri, headers=hdrs, json=body)
         resp.raise_for_status()
         return resp
 
     def delete_a_targetserver(self, environment):
-        uri = DELETE_A_TARGETSERVER_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._targetserver_name)
+        uri = DELETE_A_TARGETSERVER_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            environment=environment,
+            name=self._targetserver_name,
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.delete(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def list_targetservers_in_an_environment(self, environment, prefix=None, format='json'):
-        uri = LIST_TARGETSERVERS_IN_AN_ENVIRONMENT_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment)
+        uri = LIST_TARGETSERVERS_IN_AN_ENVIRONMENT_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return TargetserversSerializer().serialize_details(resp, format, prefix=prefix)
 
     def get_targetserver(self, environment):
-        uri = GET_TARGETSERVER_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._targetserver_name)
+        uri = GET_TARGETSERVER_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            environment=environment,
+            name=self._targetserver_name,
+        )
         hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json'})
         resp = requests.get(uri, headers=hdrs)
         resp.raise_for_status()
         return resp
 
     def update_a_targetserver(self, environment, request_body):
-        uri = UPDATE_A_TARGETSERVER_PATH.format(api_url=APIGEE_ADMIN_API_URL, org=self._org_name, environment=environment, name=self._targetserver_name)
-        hdrs = auth.set_header(self._auth, headers={'Accept': 'application/json', 'Content-Type': 'application/json'})
+        uri = UPDATE_A_TARGETSERVER_PATH.format(
+            api_url=APIGEE_ADMIN_API_URL,
+            org=self._org_name,
+            environment=environment,
+            name=self._targetserver_name,
+        )
+        hdrs = auth.set_header(
+            self._auth,
+            headers={'Accept': 'application/json', 'Content-Type': 'application/json'},
+        )
         body = json.loads(request_body)
         resp = requests.put(uri, headers=hdrs, json=body)
         resp.raise_for_status()
